==> codebuild-1.195.0-sources.jar: software/amazon/awscdk/services/codebuild/CfnReportGroupProps.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * Properties for defining a `CfnReportGroup`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.codebuild.*;
 * CfnReportGroupProps cfnReportGroupProps = CfnReportGroupProps.builder()
 *         .exportConfig(ReportExportConfigProperty.builder()
 *                 .exportConfigType("exportConfigType")
 *                 // the properties below are optional
 *                 .s3Destination(S3ReportExportConfigProperty.builder()
 *                         .bucket("bucket")
 *                         // the properties below are optional
 *                         .bucketOwner("bucketOwner")
 *                         .encryptionDisabled(false)
 *                         .encryptionKey("encryptionKey")
 *                         .packaging("packaging")
 *                         .path("path")
 *                         .build())
 *                 .build())
 *         .type("type")
 *         // the properties below are optional
 *         .deleteReports(false)
 *         .name("name")
 *         .tags(List.of(CfnTag.builder()
 *                 .key("key")
 *                 .value("value")
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.74.0 (build 6d08790)", date = "2023-03-02T14:17:21.978Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.CfnReportGroupProps")
@software.amazon.jsii.Jsii.Proxy(CfnReportGroupProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnReportGroupProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Information about the destination where the raw data of this `ReportGroup` is exported.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getExportConfig();

    /**
     * The type of the `ReportGroup` . This can be one of the following values:.
     * <p>
     * <ul>
     * <li><strong>CODE_COVERAGE</strong> - The report group contains code coverage reports.</li>
     * <li><strong>TEST</strong> - The report group contains test reports.</li>
     * </ul>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getType();

    /**
     * When deleting a report group, specifies if reports within the report group should be deleted.
     * <p>
     * <ul>
     * <li><strong>true</strong> - Deletes any reports that belong to the report group before deleting the report group.</li>
     * <li><strong>false</strong> - You must delete any reports in the report group. This is the default value. If you delete a report group that contains one or more reports, an exception is thrown.</li>
     * </ul>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getDeleteReports() {
        return null;
    }

    /**
     * The name of the `ReportGroup` .
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getName() {
        return null;
    }

    /**
     * A list of tag key and value pairs associated with this report group.
     * <p>
     * These tags are available for use by AWS services that support AWS CodeBuild report group tags.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnReportGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnReportGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnReportGroupProps> {
        java.lang.Object exportConfig;
        java.lang.String type;
        java.lang.Object deleteReports;
        java.lang.String name;
        java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Sets the value of {@link CfnReportGroupProps#getExportConfig}
         * @param exportConfig Information about the destination where the raw data of this `ReportGroup` is exported. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder exportConfig(software.amazon.awscdk.core.IResolvable exportConfig) {
            this.exportConfig = exportConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnReportGroupProps#getExportConfig}
         * @param exportConfig Information about the destination where the raw data of this `ReportGroup` is exported. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder exportConfig(software.amazon.awscdk.services.codebuild.CfnReportGroup.ReportExportConfigProperty exportConfig) {
            this.exportConfig = exportConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnReportGroupProps#getType}
         * @param type The type of the `ReportGroup` . This can be one of the following values:. This parameter is required.
         *             <ul>
         *             <li><strong>CODE_COVERAGE</strong> - The report group contains code coverage reports.</li>
         *             <li><strong>TEST</strong> - The report group contains test reports.</li>
         *             </ul>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder type(java.lang.String type) {
            this.type = type;
            return this;
        }

        /**
         * Sets the value of {@link CfnReportGroupProps#getDeleteReports}
         * @param deleteReports When deleting a report group, specifies if reports within the report group should be deleted.
         *                      <ul>
         *                      <li><strong>true</strong> - Deletes any reports that belong to the report group before deleting the report group.</li>
         *                      <li><strong>false</strong> - You must delete any reports in the report group. This is the default value. If you delete a report group that contains one or more reports, an exception is thrown.</li>
         *                      </ul>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deleteReports(java.lang.Boolean deleteReports) {
            this.deleteReports = deleteReports;
            return this;
        }

        /**
         * Sets the value of {@link CfnReportGroupProps#getDeleteReports}
         * @param deleteReports When deleting a report group, specifies if reports within the report group should be deleted.
         *                      <ul>
         *                      <li><strong>true</strong> - Deletes any reports that belong to the report group before deleting the report group.</li>
         *                      <li><strong>false</strong> - You must delete any reports in the report group. This is the default value. If you delete a report group that contains one or more reports, an exception is thrown.</li>
         *                      </ul>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deleteReports(software.amazon.awscdk.core.IResolvable deleteReports) {
            this.deleteReports = deleteReports;
            return this;
        }

        /**
         * Sets the value of {@link CfnReportGroupProps#getName}
         * @param name The name of the `ReportGroup` .
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link CfnReportGroupProps#getTags}
         * @param tags A list of tag key and value pairs associated with this report group.
         *             These tags are available for use by AWS services that support AWS CodeBuild report group tags.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.core.CfnTag> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnReportGroupProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnReportGroupProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnReportGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnReportGroupProps {
        private final java.lang.Object exportConfig;
        private final java.lang.String type;
        private final java.lang.Object deleteReports;
        private final java.lang.String name;
        private final java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.exportConfig = software.amazon.jsii.Kernel.get(this, "exportConfig", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.type = software.amazon.jsii.Kernel.get(this, "type", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.deleteReports = software.amazon.jsii.Kernel.get(this, "deleteReports", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.exportConfig = java.util.Objects.requireNonNull(builder.exportConfig, "exportConfig is required");
            this.type = java.util.Objects.requireNonNull(builder.type, "type is required");
            this.deleteReports = builder.deleteReports;
            this.name = builder.name;
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)builder.tags;
        }

        @Override
        public final java.lang.Object getExportConfig() {
            return this.exportConfig;
        }

        @Override
        public final java.lang.String getType() {
            return this.type;
        }

        @Override
        public final java.lang.Object getDeleteReports() {
            return this.deleteReports;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("exportConfig", om.valueToTree(this.getExportConfig()));
            data.set("type", om.valueToTree(this.getType()));
            if (this.getDeleteReports() != null) {
                data.set("deleteReports", om.valueToTree(this.getDeleteReports()));
            }
            if (this.getName() != null) {
                data.set("name", om.valueToTree(this.getName()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-codebuild.CfnReportGroupProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnReportGroupProps.Jsii$Proxy that = (CfnReportGroupProps.Jsii$Proxy) o;

            if (!exportConfig.equals(that.exportConfig)) return false;
            if (!type.equals(that.type)) return false;
            if (this.deleteReports != null ? !this.deleteReports.equals(that.deleteReports) : that.deleteReports != null) return false;
            if (this.name != null ? !this.name.equals(that.name) : that.name != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.exportConfig.hashCode();
            result = 31 * result + (this.type.hashCode());
            result = 31 * result + (this.deleteReports != null ? this.deleteReports.hashCode() : 0);
            result = 31 * result + (this.name != null ? this.name.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}

==> codebuild-1.204.0-sources.jar: software/amazon/awscdk/services/codebuild/CfnReportGroupProps.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * Properties for defining a <code>CfnReportGroup</code>.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.codebuild.*;
 * CfnReportGroupProps cfnReportGroupProps = CfnReportGroupProps.builder()
 *         .exportConfig(ReportExportConfigProperty.builder()
 *                 .exportConfigType("exportConfigType")
 *                 // the properties below are optional
 *                 .s3Destination(S3ReportExportConfigProperty.builder()
 *                         .bucket("bucket")
 *                         // the properties below are optional
 *                         .bucketOwner("bucketOwner")
 *                         .encryptionDisabled(false)
 *                         .encryptionKey("encryptionKey")
 *                         .packaging("packaging")
 *                         .path("path")
 *                         .build())
 *                 .build())
 *         .type("type")
 *         // the properties below are optional
 *         .deleteReports(false)
 *         .name("name")
 *         .tags(List.of(CfnTag.builder()
 *                 .key("key")
 *                 .value("value")
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.84.0 (build 5404dcf)", date = "2023-06-19T16:30:41.763Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.CfnReportGroupProps")
@software.amazon.jsii.Jsii.Proxy(CfnReportGroupProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnReportGroupProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Information about the destination where the raw data of this <code>ReportGroup</code> is exported.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getExportConfig();

    /**
     * The type of the <code>ReportGroup</code> . This can be one of the following values:.
     * <p>
     * <ul>
     * <li><strong>CODE_COVERAGE</strong> - The report group contains code coverage reports.</li>
     * <li><strong>TEST</strong> - The report group contains test reports.</li>
     * </ul>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getType();

    /**
     * When deleting a report group, specifies if reports within the report group should be deleted.
     * <p>
     * <ul>
     * <li><strong>true</strong> - Deletes any reports that belong to the report group before deleting the report group.</li>
     * <li><strong>false</strong> - You must delete any reports in the report group. This is the default value. If you delete a report group that contains one or more reports, an exception is thrown.</li>
     * </ul>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getDeleteReports() {
        return null;
    }

    /**
     * The name of the <code>ReportGroup</code> .
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getName() {
        return null;
    }

    /**
     * A list of tag key and value pairs associated with this report group.
     * <p>
     * These tags are available for use by AWS services that support AWS CodeBuild report group tags.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnReportGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnReportGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnReportGroupProps> {
        java.lang.Object exportConfig;
        java.lang.String type;
        java.lang.Object deleteReports;
        java.lang.String name;
        java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Sets the value of {@link CfnReportGroupProps#getExportConfig}
         * @param exportConfig Information about the destination where the raw data of this <code>ReportGroup</code> is exported. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder exportConfig(software.amazon.awscdk.core.IResolvable exportConfig) {
            this.exportConfig = exportConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnReportGroupProps#getExportConfig}
         * @param exportConfig Information about the destination where the raw data of this <code>ReportGroup</code> is exported. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder exportConfig(software.amazon.awscdk.services.codebuild.CfnReportGroup.ReportExportConfigProperty exportConfig) {
            this.exportConfig = exportConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnReportGroupProps#getType}
         * @param type The type of the <code>ReportGroup</code> . This can be one of the following values:. This parameter is required.
         *             <ul>
         *             <li><strong>CODE_COVERAGE</strong> - The report group contains code coverage reports.</li>
         *             <li><strong>TEST</strong> - The report group contains test reports.</li>
         *             </ul>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder type(java.lang.String type) {
            this.type = type;
            return this;
        }

        /**
         * Sets the value of {@link CfnReportGroupProps#getDeleteReports}
         * @param deleteReports When deleting a report group, specifies if reports within the report group should be deleted.
         *                      <ul>
         *                      <li><strong>true</strong> - Deletes any reports that belong to the report group before deleting the report group.</li>
         *                      <li><strong>false</strong> - You must delete any reports in the report group. This is the default value. If you delete a report group that contains one or more reports, an exception is thrown.</li>
         *                      </ul>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deleteReports(java.lang.Boolean deleteReports) {
            this.deleteReports = deleteReports;
            return this;
        }

        /**
         * Sets the value of {@link CfnReportGroupProps#getDeleteReports}
         * @param deleteReports When deleting a report group, specifies if reports within the report group should be deleted.
         *                      <ul>
         *                      <li><strong>true</strong> - Deletes any reports that belong to the report group before deleting the report group.</li>
         *                      <li><strong>false</strong> - You must delete any reports in the report group. This is the default value. If you delete a report group that contains one or more reports, an exception is thrown.</li>
         *                      </ul>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deleteReports(software.amazon.awscdk.core.IResolvable deleteReports) {
            this.deleteReports = deleteReports;
            return this;
        }

        /**
         * Sets the value of {@link CfnReportGroupProps#getName}
         * @param name The name of the <code>ReportGroup</code> .
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link CfnReportGroupProps#getTags}
         * @param tags A list of tag key and value pairs associated with this report group.
         *             These tags are available for use by AWS services that support AWS CodeBuild report group tags.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.core.CfnTag> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnReportGroupProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnReportGroupProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnReportGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnReportGroupProps {
        private final java.lang.Object exportConfig;
        private final java.lang.String type;
        private final java.lang.Object deleteReports;
        private final java.lang.String name;
        private final java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.exportConfig = software.amazon.jsii.Kernel.get(this, "exportConfig", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.type = software.amazon.jsii.Kernel.get(this, "type", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.deleteReports = software.amazon.jsii.Kernel.get(this, "deleteReports", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.exportConfig = java.util.Objects.requireNonNull(builder.exportConfig, "exportConfig is required");
            this.type = java.util.Objects.requireNonNull(builder.type, "type is required");
            this.deleteReports = builder.deleteReports;
            this.name = builder.name;
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)builder.tags;
        }

        @Override
        public final java.lang.Object getExportConfig() {
            return this.exportConfig;
        }

        @Override
        public final java.lang.String getType() {
            return this.type;
        }

        @Override
        public final java.lang.Object getDeleteReports() {
            return this.deleteReports;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("exportConfig", om.valueToTree(this.getExportConfig()));
            data.set("type", om.valueToTree(this.getType()));
            if (this.getDeleteReports() != null) {
                data.set("deleteReports", om.valueToTree(this.getDeleteReports()));
            }
            if (this.getName() != null) {
                data.set("name", om.valueToTree(this.getName()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-codebuild.CfnReportGroupProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnReportGroupProps.Jsii$Proxy that = (CfnReportGroupProps.Jsii$Proxy) o;

            if (!exportConfig.equals(that.exportConfig)) return false;
            if (!type.equals(that.type)) return false;
            if (this.deleteReports != null ? !this.deleteReports.equals(that.deleteReports) : that.deleteReports != null) return false;
            if (this.name != null ? !this.name.equals(that.name) : that.name != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.exportConfig.hashCode();
            result = 31 * result + (this.type.hashCode());
            result = 31 * result + (this.deleteReports != null ? this.deleteReports.hashCode() : 0);
            result = 31 * result + (this.name != null ? this.name.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}
